package com.example.tdl.web;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.oss.OSSClient;
import com.csvreader.CsvWriter;
import com.example.tdl.domain.dto.CommFeedback;
import com.example.tdl.domain.vo.*;
import com.example.tdl.service.*;
import com.example.tdl.service.redis.InfoRedisService;
import com.example.tdl.service.redis.RealRedisService;

import com.example.tdl.service.redis.TokenRedisService;
import com.example.tdl.util.AliyunOSSClientUtil;
import com.example.tdl.util.DataUtil;
import com.example.tdl.util.ZipCompressUtil;
import com.google.gson.Gson;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.apache.commons.lang3.StringUtils;
import org.influxdb.dto.Query;
import org.influxdb.dto.QueryResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import org.springframework.data.influxdb.InfluxDBTemplate;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.nio.charset.Charset;
import java.text.ParseException;
import java.text.SimpleDateFormat;

import java.util.*;

@RestController
public class DataController {
    private Logger logger = LoggerFactory.getLogger(DataController.class);

    Gson gson = new Gson();

    CommFeedback fb = new CommFeedback();

    @Autowired
    private TDLDeviceService tdlDeviceService;

    @Autowired
    private InfoRedisService infoRedisService;

    @Autowired
    private InfluxDBTemplate influxDBTemplate;

    @Autowired
    private CircuitService circuitService;

    @Autowired
    private TDLLogService tdlLogService;

    @Autowired
    private TokenRedisService tokenRedisService;

    @Autowired
    private RealRedisService realRedisService;

    @Autowired
    private ProbesService probesService;

//    @Autowired
//    private  InfluxDBService influxDBService;

    @Autowired
    private I18nController i18n;

    private final static String database = "original";

    private List<String> list = new ArrayList<String>() {{
        add("\"T\"");
        add("\"h\"");
        add("\"p\"");
        add("\"a0\"");
        add("\"ta\"");
    }};

    //获取坐标数据数据
    @ApiOperation(value = "获取坐标数据数据", notes = "获取坐标数据数据:" +
            "   time:时间," +
            "   lng：经度," +
            "   lat: 纬度.")
    @PostMapping("/getLocation")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
            @ApiImplicitParam(paramType = "header", name = "AccountLanguage", value = "language", required = false, dataType = "String"),
    })
    public Object getLocation(@RequestBody SearchLocationVo searchLocationVo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(searchLocationVo.getTransportationNo())) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        //根据运输编号获取线路信息
        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(searchLocationVo.getTransportationNo(), user.getCompanyNo());
        List<LocationDataVo> locationDataVoList = new ArrayList<>();
        if (resultCircuitVo == null) {
            return gson.toJson(locationDataVoList);
        }
        if (resultCircuitVo.getStartTime() == null || resultCircuitVo.getStartTime() == 0) {
            return gson.toJson(locationDataVoList);
        }
        Long startTime = resultCircuitVo.getStartTime() * 1000000l;
        if(resultCircuitVo.getEndTime() !=null  && infoRedisService.hasHashKey("TransportConfig",searchLocationVo.getTransportationNo())){
            Object ret = infoRedisService.getHash("TransportConfig",searchLocationVo.getTransportationNo());
            return ret;
        }
        //获取gateway的信息
        TDLLogVo tdlLogVo = tdlLogService.getByTransportationNo(searchLocationVo.getTransportationNo());
        if (tdlLogVo == null) {
            return gson.toJson(locationDataVoList);
        }
        String device = tdlLogVo.getgType() + "_" + tdlLogVo.getgSN();
        String sql = "";
        if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
            Long time = resultCircuitVo.getEndTime() * 1000000l;
            if ("baidu".equals(searchLocationVo.getType())) {
                sql = "SELECT \"bdlng\",\"bdlat\" FROM \"tdl_policy\".\"" + device + "\"where  \"data_type\" = 'location' and time >= " + startTime + "  and time<= " + time + "  ORDER BY time ";
            } else {
                sql = "SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\"" + device + "\"where \"data_type\" = 'location' and  time >= " + startTime + "  and time<= " + time + "  ORDER BY time ";
            }
        } else {
            if ("baidu".equals(searchLocationVo.getType())) {
                sql = "SELECT \"bdlng\",\"bdlat\" FROM \"tdl_policy\".\"" + device + "\"where \"data_type\" = 'location' and  time >= " + startTime + "  ORDER BY time ";
            } else {
                sql = "SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\"" + device + "\"where  \"data_type\" = 'location' and time >= " + startTime + "  ORDER BY time ";
            }
        }
        //获取tdl信息
        QueryResult queryResult = influxDBTemplate.query(new Query(sql, database));
        //解析经纬度数据
        List<LocationDataVo> locationDataVos = new ArrayList<>();
        if (queryResult.getResults().get(0).getSeries() != null) {
            locationDataVos = getLocation(queryResult);
        }
        //获取震动的数据
        String sql2 = "";
        if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
            Long time = resultCircuitVo.getEndTime() * 1000000l;
            sql2 = "SELECT \"a0\" FROM \"tdl_policy\".\"" + device + "\"where \"event\" = 'Shock event' and  time >= " + startTime + " and time<=" + time + "  ORDER BY time";
        } else {
            sql2 = "SELECT \"a0\" FROM \"tdl_policy\".\"" + device + "\"where \"event\" = 'Shock event' and  time >= " + startTime + " ORDER BY time";
        }
        QueryResult queryResult2 = influxDBTemplate.query(new Query(sql2, database));
        List<String> timeList = new ArrayList<>();
        if (queryResult2.getResults().get(0).getSeries() != null) {
            //获取震动的时间戳
            timeList = getTime(queryResult2);
        }
        if (timeList.size() > 0) {
            //获取震动数据的坐标
            String sql3 = "";
            for (String time : timeList) {
                Long t = Long.valueOf(time) * 1000000l;
                if ("baidu".equals(searchLocationVo.getType())) {
                    sql3 = "SELECT \"bdlng\",\"bdlat\" FROM \"tdl_policy\".\"" + device + "\" where \"data_type\" = 'location' and  time >= " + startTime + " and time<=" + t + " ORDER BY time desc limit 1;" + sql3;
                } else {
                    sql3 = "SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\"" + device + "\" where  \"data_type\" = 'location' and time >= " + startTime + " and time<=" + t + " ORDER BY time desc limit 1;" + sql3;
                }
            }
            QueryResult queryResult3 = influxDBTemplate.query(new Query(sql3, database));
            List<String> time = new ArrayList<>();
            if (queryResult3.getResults() != null) {
                time = getShockLocation(queryResult3);
            }
            for (LocationDataVo locationDataVo : locationDataVos) {
                if (time.contains(locationDataVo.getTime())) {
                    locationDataVo.setError(1);
                    locationDataVoList.add(locationDataVo);
                } else {
                    locationDataVo.setError(0);
                    locationDataVoList.add(locationDataVo);
                }
            }
            //如果是已经完结保存到redis中
            if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
                Map<Object, Object> map = new HashMap<>();
                map.put(searchLocationVo.getTransportationNo(), locationDataVoList.toString());
                infoRedisService.setHash("TransportConfig", map, System.currentTimeMillis());
            }
            return gson.toJson(locationDataVoList);
        } else {
            //如果是已经完结保存到redis中
            if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
                Map<Object, Object> map = new HashMap<>();
                map.put(searchLocationVo.getTransportationNo(), locationDataVos.toString());
                infoRedisService.setHash("TransportConfig", map,System.currentTimeMillis());
            }
            return gson.toJson(locationDataVos);
        }
    }


    //获取历史数据
//    @ApiOperation(value = "获取历史数据", notes = "获取历史数据:")
//    @PostMapping("/getHistoryData")
//    @ApiImplicitParams({
//            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
//            @ApiImplicitParam(paramType = "header", name = "AccountLanguage", value = "language", required = false, dataType = "String"),
//    })
//    public Object getHistoryData(@RequestBody String transportationNo, HttpServletRequest request) {
//        String token = request.getHeader("Account_token");
//        String datum = tokenRedisService.get("TOKEN_" + token);
//        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
//        String port = request.getHeader("AccountLanguage");
//        JSONObject jsonObject = JSON.parseObject(transportationNo);
//        transportationNo = jsonObject.getString("transportationNo");
//        List<DataVo> dataVoList = new ArrayList<>();
//        if (StringUtils.isEmpty(transportationNo)) {
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request, "transportationNo"));
//            return gson.toJson(fb);
//        }
//        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo, user.getCompanyNo());
//        if (resultCircuitVo == null) {
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request, "noCircuit"));
//            return gson.toJson(fb);
//        }
//        if (resultCircuitVo.getStartTime() == null || resultCircuitVo.getStartTime() == 0) {
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request, "notStarted"));
//            return gson.toJson(fb);
//        }
//        Long startTime = resultCircuitVo.getStartTime() * 1000000l;
//        TDLLogVo gatewayVo = tdlLogService.getByTransportationNo(transportationNo);
//        if (gatewayVo == null) {
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request, "noCircuit"));
//            return gson.toJson(fb);
//        }
//        String device = gatewayVo.getgType() + "_" + gatewayVo.getgSN();
//        //获取tdl信息
//        List<String> devList = tdlLogService.getTdlSN(transportationNo);
//        if (devList.size() == 0) {
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request, "noCircuit"));
//            return gson.toJson(fb);
//        }
//        Map<String, String> map = new HashMap<>();
//        map.put("\"T\"", "temp");
//        map.put("\"h\"", "humidity");
//        map.put("\"p\"", "pressure");
//        map.put("\"a0\"", "shockEnergy");
//        map.put("\"a1\"", "shock");
//        map.put("\"ta\"", "tilt");
//        for (int j = 0; j < list.size(); j++) {
//            DataVo dataVo = new DataVo();
//            dataVo.setDescription(map.get(list.get(j)));
//            List<HistoryDataVo> historyDataVoList = new ArrayList<>();
//            for (int i = 0; i < devList.size(); i++) {
//                HistoryDataVo historyDataVo = new HistoryDataVo();
//                String TDLSN = devList.get(i).replace("TDL-", "").trim();
//                historyDataVo.setTDLSN(TDLSN);
//                ResultAlarmVo resultAlarmVo = tdlLogService.getByTdl(transportationNo, TDLSN);
//                if (list.get(j).equals("\"T\"")) {
//                    //根据tdl货物报警信息
//                    historyDataVo.setMax(resultAlarmVo.getTemMax().toString());
//                    historyDataVo.setMin(resultAlarmVo.getTemMin().toString());
//                } else if (list.get(j).equals("\"h\"")) {
//                    historyDataVo.setMax(resultAlarmVo.getHumidityMax().toString());
//                    historyDataVo.setMin(resultAlarmVo.getHumidityMin().toString());
//                }
//                List<HistoryData> historyData = new ArrayList<>();
//                String sqls = "";
//                if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
//                    sqls = "SELECT count(" + list.get(j) + ") FROM \"tdl_policy\".\"" + device + "\" WHERE \"tdl\"='" + devList.get(i) + "'  and time>=" + startTime + " and time <=" + resultCircuitVo.getEndTime() * 1000000l;
//                } else {
//                    sqls = "SELECT count(" + list.get(j) + ") FROM \"tdl_policy\".\"" + device + "\" WHERE \"tdl\"='" + devList.get(i) + "'  and time>=" + startTime + " and time <=" + System.currentTimeMillis() * 1000000l;
//                }
//                QueryResult queryResults = influxDBTemplate.query(new Query(sqls, database));
//                Integer count;
//                if (queryResults.getResults().get(0).getSeries() != null) {
//                    count = Double.valueOf(queryResults.getResults().get(0).getSeries().get(0).getValues().get(0).get(1).toString()).intValue();
//                } else {
//                    historyDataVo.setDataList(historyData);
//                    historyDataVoList.add(historyDataVo);
//                    continue;
//                }
//                String sql = "";
//                if (count > 500) {
//                    if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
//                        sql = DataUtil.getSQL(gatewayVo.getgSN(),list.get(j), device, devList.get(i), startTime, resultCircuitVo.getEndTime() * 1000000l);
//                    } else {
//                        sql = DataUtil.getSQL(gatewayVo.getgSN(),list.get(j), device, devList.get(i), startTime, System.currentTimeMillis() * 1000000l);
//                    }
//                    QueryResult queryResult = influxDBTemplate.query(new Query(sql, database));
//                    if (queryResult.getResults() != null) {
//                        historyData =DataUtil.getHistoryDatas(queryResult, list.get(j));
//                    }
//                    historyDataVo.setDataList(historyData);
//                    historyDataVoList.add(historyDataVo);
//                } else {
//                    if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
//                        sql = "SELECT " + list.get(j) + " FROM \"tdl_policy\".\"" + device + "\" where \"tdl\"='" + devList.get(i) + "'  and time >=" + startTime + "  and time<=" + resultCircuitVo.getEndTime() * 1000000l + " ORDER BY time ";
//                    } else {
//                        sql = "SELECT " + list.get(j) + " FROM \"tdl_policy\".\"" + device + "\" where \"tdl\"='" + devList.get(i) + "'  and time >=" + startTime + "  ORDER BY time";
//                    }
//                    QueryResult queryResult = influxDBTemplate.query(new Query(sql, database));
//                    if (queryResult.getResults().get(0).getSeries() != null) {
//                        //解析数据
//                        historyData = DataUtil.getHistoryData(queryResult, list.get(j));
//                    }
//                    historyDataVo.setDataList(historyData);
//                    historyDataVoList.add(historyDataVo);
//                }
//
//            }
//            dataVo.setDataList(historyDataVoList);
//            dataVoList.add(dataVo);
//        }
//        return gson.toJson(dataVoList);
//    }


    @ApiOperation(value = "获取温度数据", notes = "获取温度数据:" +
            "   TDLSN:tdl编号," +
            "   temperatureDataVos:," +
            "   time:时间," +
            "   value:温度数据.")
    @PostMapping("/getTemperature")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getTemperature(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"T\"","Regular measurement");
    }



    @ApiOperation(value = "获取温度数据", notes = "获取温度数据:" +
            "   TDLSN:tdl编号," +
            "   temperatureDataVos:," +
            "   time:时间," +
            "   value:温度数据.")
    @PostMapping("/getHumidity")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getHumidity(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"h\"","Regular measurement");
    }



    //获取倾斜度数据
    @ApiOperation(value = "获取倾斜度数据", notes = "获取倾斜度数据")
    @PostMapping("/getTiltAngle")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getTiltAngle(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"ta\"","TIlt event");
    }


    //获取震动能量
    @ApiOperation(value = "获取震动能量", notes = "获取震动能量")
    @PostMapping("/getShockEnergy")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getShockEnergy(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"a0\"","Shock event");
    }


    @ApiOperation(value = "获取震动能量", notes = "获取震动能量")
    @PostMapping("/getShock")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getShock(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"a1\"","Shock event");
    }


    @ApiOperation(value = "获取震动能量", notes = "获取震动能量")
    @PostMapping("/getPressure")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getPressure(@RequestBody String transportationNo, HttpServletRequest request) {
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        return DataUtil.getData(transportationNo,request,i18n,user.getCompanyNo(),circuitService,tdlLogService,influxDBTemplate,database,"\"p\"","Regular measurement");
    }


    //下载数据
    @ApiOperation(value = "下载线路数据", notes = "下载线路数据")
    @PostMapping("/downLoad")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public String downLoad(@RequestBody String transportationNo, HttpServletRequest request){
        String token = request.getHeader("Account_token");
        String datum = tokenRedisService.get("TOKEN_" + token);
        UserRedisVo user = gson.fromJson(datum, UserRedisVo.class);
        if (StringUtils.isEmpty(transportationNo)) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "transportationNo"));
            return gson.toJson(fb);
        }
        JSONObject jsonObject = JSON.parseObject(transportationNo);
        transportationNo = jsonObject.getString("transportationNo");
        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo, user.getCompanyNo());
        if (resultCircuitVo == null) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "noCircuit"));
            return gson.toJson(fb);
        }
        if (resultCircuitVo.getStartTime() == null || resultCircuitVo.getStartTime() == 0) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "notStarted"));
            return gson.toJson(fb);
        }
        Long startTime = resultCircuitVo.getStartTime() * 1000000l;
        TDLLogVo gatewayVo = tdlLogService.getByTransportationNo(transportationNo);
        if (gatewayVo == null) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "noCircuit"));
            return gson.toJson(fb);
        }
        String device = gatewayVo.getgType() + "_" + gatewayVo.getgSN();
        //获取tdl信息
        List<String> devList = tdlLogService.getTdlSN(transportationNo);
        if (devList.size() == 0) {
            fb.setCode(0);
            fb.setMessage(i18n.getMessage(request, "noCircuit"));
            return gson.toJson(fb);
        }
        OSSClient ossClient = AliyunOSSClientUtil.getOSSClient();
        String[] rowsName = new String[]{"时间","压力(MPa)","温度(℃)","湿度(%RH)","震动能量(w)","震动强度(g)","倾斜角度(°)","经度","纬度"};
        File file = new File("./export");
        if(!file.exists()){
            file.mkdir();
        }
        try {
                String sqls = "";
                if (resultCircuitVo.getEndTime() != null && resultCircuitVo.getEndTime() != 0) {
                    sqls = "SELECT  \"tdl\",\"p\",\"T\",\"h\",\"a0\",\"a1\",\"ta\",\"bdlng\",\"bdlat\"  FROM \"tdl_policy\".\""+device+"\" WHERE   time >=" +startTime +"  and  time <=" +resultCircuitVo.getEndTime() * 1000000l+" ORDER BY time ";
                } else {
                    sqls = "SELECT  \"tdl\",\"p\",\"T\",\"h\",\"a0\",\"a1\",\"ta\",\"bdlng\",\"bdlat\"  FROM \"tdl_policy\".\""+device+"\" WHERE   time >=" +startTime +"  and  time <=" +System.currentTimeMillis() * 1000000l+" ORDER BY time ";
                }
                QueryResult queryResult = influxDBTemplate.query(new Query(sqls, database));
                 File[] srcFiles = new File[devList.size()];
                 File zipFile = new File("./export/" +transportationNo+"运输数据.zip");
                if (queryResult.getResults().get(0).getSeries().get(0) != null) {

                    for(int  i = 0;i<devList.size();i++){

                        CsvWriter csvWriter = new CsvWriter("./export/"+devList.get(i).replace("TDL-", "").trim()+"运输数据.csv" , ',', Charset.forName("GB2312"));
                        csvWriter.writeRecord(rowsName);
                        List<List<Object>> values =  getValues(queryResult);
                        for(List<Object> value : values){
//                            logger.info(value.get(1)==null ? "  " :value.get(1).toString() +"---------"+devList.get(i));
                            if(value.get(1) == null || value.get(1).toString().equals(devList.get(i))){
                                String[] objs = new String[rowsName.length];
                                for (int j = 0; j < objs.length; j++) {
                                    if(j==0){
                                        try {
                                            objs[j] =timeStampDate(new Long(dateToStamp(String.valueOf(value.get(j)))));
                                        } catch (Exception e) {
                                            e.printStackTrace();
                                            fb.setMessage("时间解析异常");
                                        }
                                    }else {
                                        objs[j] =value.get(j+1) == null ? "-" :value.get(j+1).toString();
                                    }
                                }
                                csvWriter.writeRecord(objs);
                                csvWriter.flush();
                            }
                        }
                        csvWriter.close();
                        srcFiles[i]=new File("./export/"+devList.get(i).replace("TDL-", "").trim()+"运输数据.csv");
                    }
                }

            ZipCompressUtil.zipFiles(srcFiles,zipFile);
            try {
                String md5Key = AliyunOSSClientUtil.uploadObject2OSS(ossClient, zipFile);
                if (md5Key != null) {
                    for(int a =0;a<srcFiles.length;a++){
                        srcFiles[a].delete();
                    }
                    zipFile.delete();
                    fb.setCode(1);
                    fb.setMessage("https://tdlcloud.oss-cn-shanghai.aliyuncs.com/circuit/"+transportationNo+"运输数据.zip");
                    return gson.toJson(fb);
                } else {
                    fb.setCode(0);
                    fb.setMessage("上传失败");
                }
            } catch (Exception e) {
                e.printStackTrace();
                logger.info(e.toString());
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.info(e.toString());
        }

        return  gson.toJson(fb);
    }




    //解析数据
    public List<LocationDataVo> getLocation(QueryResult queryResult) {
        List<List<Object>> values = getValues(queryResult);
        List<LocationDataVo> historyDataList = new ArrayList<>();
        for (List<Object> value : values) {
            LocationDataVo historyData = new LocationDataVo();
            if (value.get(1).toString().equals("0.0")) {
                continue;
            } else {
                historyData.setTime(parseTime(value.get(0).toString()));
                historyData.setLng(Double.parseDouble(value.get(1).toString()));
                historyData.setLat(Double.parseDouble(value.get(2).toString()));
                historyData.setError(0);
            }

            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    //解析数据格式
    public List<List<Object>> getValues(QueryResult queryResult) {
        List<List<Object>> values = new ArrayList<>();
        for (QueryResult.Result result : queryResult.getResults()) {
            if (result.getSeries() != null) {
                for (QueryResult.Series series : result.getSeries()) {
                    if (series != null) {
                        values = series.getValues();
                    }
                }
            }
        }
        return values;
    }

    //将utc时间转换成时间戳
    public static String dateToStamp(String s) throws ParseException {
        Date date = null;
        if (s.length() != 20) {
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'").parse(s);
        } else {
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'").parse(s);
        }
        return String.valueOf(date.getTime());
    }

    //解析时间
    public String parseTime(String time) {
        String dateResult = null;
        try {
            dateResult = dateToStamp(time);
        } catch (ParseException e) {
            e.printStackTrace();
            logger.info(e.toString());
            fb.setCode(0);
            fb.setMessage("解析时间异常");
        }
        return dateResult;
    }

    //判断两个时间相差多少
    public static String getDistanceTime(Long time1, Long time2) {
        //获取当前时区，将时间戳转化成日期时间格式
        Date t1 = new Date(time1);
        Date t2 = new Date(time2);
        int days = differentDays(t1, t2);
        if (days > 0) {
            return days + "天";
        } else {
            return "a little minute";
        }
    }

    public static int differentDays(Date date1, Date date2) {
        Calendar cal1 = Calendar.getInstance();
        cal1.setTime(date1);

        Calendar cal2 = Calendar.getInstance();
        cal2.setTime(date2);
        int day1 = cal1.get(Calendar.DAY_OF_YEAR);
        int day2 = cal2.get(Calendar.DAY_OF_YEAR);

        int year1 = cal1.get(Calendar.YEAR);
        int year2 = cal2.get(Calendar.YEAR);
        if (year1 != year2) { //不同年
            int timeDistance = 0;
            for (int i = year1; i < year2; i++) {
                if (i % 4 == 0 && i % 100 != 0 || i % 400 == 0) {   //闰年
                    timeDistance += 366;
                } else {    //不是闰年
                    timeDistance += 365;
                }
            }
            return timeDistance + (day2 - day1);
        } else {
            return day2 - day1;
        }
    }

    //将时间戳转成时间
    public static String timeStamp2Date(Long seconds) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return sdf.format(new Date(seconds));
    }

    public static String timeStampDate(Long seconds) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月dd日 HH时mm分ss秒");
        return sdf.format(new Date(seconds));
    }

    //解析震动时间
    public List<String> getTime(QueryResult queryResult) {
        List<List<Object>> values = getValues(queryResult);
        List<String> time = new ArrayList<>();
        for (List<Object> value : values) {
            try {
                time.add(UTCToCST(value.get(0).toString()));
            } catch (Exception e) {
                e.printStackTrace();
                logger.info(e.toString());
            }
        }
        return time;
    }


    public String UTCToCST(String UTCStr) {
        Date date = null;
        try {
            if (UTCStr.length() != 20) {
                date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'").parse(UTCStr);
            } else {
                date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'").parse(UTCStr);
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.info(e.toString());
        }
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.HOUR, calendar.get(Calendar.HOUR) + 8);
        //calendar.getTime() 返回的是Date类型，也可以使用calendar.getTimeInMillis()获取时间戳
        //format的格式可以任意
        return String.valueOf(calendar.getTimeInMillis());
    }


    public List<String> getShockLocation(QueryResult queryResult) {
        List<List<Object>> values = new ArrayList<>();
        for (QueryResult.Result result : queryResult.getResults()) {
            if (result.getSeries() != null) {
                for (QueryResult.Series series : result.getSeries()) {
                    if (series != null) {
                        values.add(series.getValues().get(0));
                    }
                }
            }
        }
        List<String> timeList = new ArrayList<>();
        for (List<Object> value : values) {
            timeList.add(parseTime(value.get(0).toString()));
        }
        return timeList;
    }


    public List<DeviceDataVo> getDeviceData(QueryResult queryResult) {
        List<List<Object>> values = getValues(queryResult);
        List<DeviceDataVo> historyDataList = new ArrayList<>();
        for (List<Object> value : values) {
            DeviceDataVo historyData = new DeviceDataVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setTemperature(value.get(1) == null ? "" : value.get(1).toString());
            historyData.setHumidity(value.get(2) == null ? "" : value.get(2).toString());
            historyData.setPressure(value.get(3) == null ? "" : value.get(3).toString());
            historyData.setShockEnergy(value.get(4) == null ? "" : value.get(4).toString());
            historyData.setTiltAngle(value.get(5) == null ? "" : value.get(5).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }



}

//    获取历史数据
//    @ApiOperation(value = "获取历史数据",notes = "获取历史数据:")
//    @PostMapping("/getHistoryData")
//    @ApiImplicitParams({
//            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
//            @ApiImplicitParam(paramType="header", name = "AccountLanguage", value = "language", required = false, dataType = "String"),
//    })
//    public Object getHistoryData(@RequestBody String transportationNo,HttpServletRequest request){
//        String token = request.getHeader("Account_token");
//        String datum = tokenRedisService.get("TOKEN_" +token);
//        UserRedisVo user =  gson.fromJson(datum,UserRedisVo.class);
//        String port = request.getHeader("AccountLanguage");
//        logger.info("" +System.currentTimeMillis());
//        logger.info("" + Calendar.getInstance().getTimeInMillis());
//        JSONObject jsonObject= JSON.parseObject(transportationNo);
//        transportationNo=jsonObject.getString("transportationNo");
//        List<DataVo> dataVoList = new ArrayList<>();
//        if(StringUtils.isEmpty(transportationNo)){
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request,"transportationNo"));
//            return gson.toJson(fb);
//        }
//        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo,user.getCompanyName());
//        if(resultCircuitVo ==null){
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request,"noCircuit"));
//            return gson.toJson(fb);
//        }
//        if(resultCircuitVo.getStartTime() == null || resultCircuitVo.getStartTime() == 0){
//            fb.setCode(0);
//            fb.setMessage(i18n.getMessage(request,"notStarted"));
//            return gson.toJson(fb);
//        }
//        Long startTime = resultCircuitVo.getStartTime() *1000000l;
//        if(resultCircuitVo.getEndTime() !=null && resultCircuitVo.getEndTime() !=0 && infoRedisService.hasHashKey("HistoryData",transportationNo)){
//            return infoRedisService.getHash("HistoryData",transportationNo);
//        }else{
//            TDLLogVo gatewayVo = tdlLogService.getByTransportationNo(transportationNo);
//            if(gatewayVo == null){
//                fb.setCode(0);
//                fb.setMessage(i18n.getMessage(request,"noCircuit"));
//                return gson.toJson(fb);
//            }
//            String device = gatewayVo.getgType() +"_" +gatewayVo.getgSN();
//            //获取tdl信息
//            List<String>  devList= tdlLogService.getTdlSN(transportationNo);
//            if(devList.size() == 0){
//                fb.setCode(0);
//                fb.setMessage(i18n.getMessage(request,"noCircuit"));
//                return gson.toJson(fb);
//            }
//            Map<String,String> map = new HashMap<>();
//            map.put("\"T\"","temp");
//            map.put("\"h\"","humidity");
//            map.put("\"p\"","pressure");
//            map.put("\"a0\"","shockEnergy");
//            map.put("\"ta\"","tilt");
//            for(int j = 0;j< list.size();j++){
//                DataVo dataVo = new DataVo();
//                dataVo.setDescription(map.get(list.get(j)));
//                List<HistoryDataVo> historyDataVoList = new ArrayList<>();
//                for( int i =0;i<devList.size();i++){
//                    HistoryDataVo historyDataVo = new HistoryDataVo();
//                    String TDLSN=devList.get(i).replace("TDL-","").trim();
//                    historyDataVo.setTDLSN(TDLSN);
//                   ResultAlarmVo resultAlarmVo =  tdlLogService.getByTdl(transportationNo,TDLSN);
//                    if(list.get(j).equals("\"T\"") ){
//                        //根据tdl货物报警信息
//                        dataVo.setMax(resultAlarmVo.getTemMax().toString());
//                        dataVo.setMin(resultAlarmVo.getTemMin().toString());
//                    }else if(list.get(j).equals("\"h\"")){
//                        dataVo.setMax(resultAlarmVo.getHumidityMax().toString());
//                        dataVo.setMin(resultAlarmVo.getHumidityMin().toString());
//                    }
//                    String sql="";
//                    if(resultCircuitVo.getEndTime() !=null && resultCircuitVo.getEndTime() !=0){
//                        sql = "SELECT "+list.get(j)+" FROM \"tdl_policy\".\""+device+"\" where \"tdl\"='"+devList.get(i)+"'  and time >="+startTime + "  and time<="+resultCircuitVo.getEndTime() *1000000l+" ORDER BY time ";
//                    }else{
//                        sql = "SELECT "+list.get(j)+" FROM \"tdl_policy\".\""+device+"\" where \"tdl\"='"+devList.get(i)+"'  and time >="+startTime + " ORDER BY time ";
//                    }
//                    QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//                    List<HistoryData>  historyData = new ArrayList<>();
//                    if(queryResult.getResults().get(0).getSeries() != null){
//                        //解析数据
//                        historyData = getHistoryData(queryResult,list.get(j));
//                    }
//                    historyDataVo.setDataList(historyData);
//                    historyDataVoList.add(historyDataVo);
//                }
//                dataVo.setDataList(historyDataVoList);
//                dataVoList.add(dataVo);
//            }
//            if(resultCircuitVo.getEndTime()!=null && resultCircuitVo.getEndTime()!=0){
//                Map<Object,Object> m = new HashMap<>();
//                map.put(transportationNo,dataVoList.toString());
//                infoRedisService.setHash("HistoryData",m,System.currentTimeMillis());
//            }
//            return  gson.toJson(dataVoList);
//        }
//    }

//    根据运输编号获取路线以及设备信息
//    @ApiOperation(value = "获取路线以及设备信息",notes = "获取路线以及设备信息" +
//            "transportationNo:运输编号" +
//            "startCity:启运城市" +
//            "startTime:开始时间" +
//            "endCity:目的城市" +
//            "endTime:结束时间（未结束为\"\"）" +
//            "gatewaySN:网关编号" +
//            "battery:网关点量" +
//            "TDLSN:tdl编号" +
//            "batteryVoltage:tdl电压" +
//            "lastTime：运输时长（未结束为\"\"）" +
//            "circuitState:运输状态(0--未开始，1--运输中，2--完成)" +
//            "remark：备注信息")
//    @PostMapping("/getCircuit")
//    @ApiImplicitParams({
//        @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
//    })
//    public Object  getCircuit(@RequestBody String transportationNo,HttpServletRequest request){
//        String token = request.getHeader("Account_token");
//        String datum = tokenRedisService.get("TOKEN_" +token);
//        UserRedisVo user =  gson.fromJson(datum,UserRedisVo.class);
//        JSONObject jsonObject= JSON.parseObject(transportationNo);
//        transportationNo=jsonObject.getString("transportationNo");
//        ResultCircuit resultCircuit = new ResultCircuit();
//        resultCircuit.setTransportationNo(transportationNo);
//        //根据运输编号获取线路信息，设备信息
//        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo,user.getCompanyName());
//        resultCircuit.setStartCity(resultCircuitVo.getStartCity());
//        resultCircuit.setStartTime(resultCircuitVo.getStartTime());
//        resultCircuit.setEndCity(resultCircuitVo.getEndCity());
//        ResultGatewayVo gatewayVo = new ResultGatewayVo();
//        if(resultCircuitVo.getEndTime() == 0){
//            resultCircuit.setEndTime(null);
//            resultCircuit.setLastTime(null);
//            gatewayVo = circuitService.getByNo(transportationNo);
//        }else{
//            resultCircuit.setEndTime(resultCircuitVo.getEndTime());
//            resultCircuit.setLastTime(getDistanceTime(resultCircuit.getStartTime(),resultCircuit.getEndTime()));
//            gatewayVo = tdlLogService.getByNo(transportationNo);
//        }
//        //获取gateway的信息
//        if(gatewayVo==null){
//            fb.setCode(0);
//            fb.setMessage("该线路未绑定设备");
//            return gson.toJson(fb);
//        }
//        resultCircuit.setGatewaySN(gatewayVo.getSN());
//        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
//        Long startTime = resultCircuitVo.getStartTime() *1000000l;
//        //获取tdl信息
//        String sql = "SELECT \"battery\"  FROM \"tdl_policy\".\""+device+"\" where time >= "+startTime +"  ORDER BY time  desc limit 1";
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        if(queryResult.getResults().get(0).getSeries() != null){
//            List<List<Object>> values = getValues(queryResult);
//            for(List<Object> value:values){
//                logger.info(value.get(1).toString());
//                resultCircuit.setBattery(value.get(1)==null ?  "": value.get(1).toString());
//            }
//        }
//        //获取tdl信息
//        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
//        String key=gatewayVo.getSN()+"_"+gatewayVo.getType() +":"+gatewayVo.getSN()+"_"+gatewayVo.getType() ;
//        //获取网关以及TDL的电量
//        if(devList.size() == 0 ){
//            fb.setCode(0);
//            fb.setMessage("该线路未绑定设备");
//            return gson.toJson(fb);
//        }
//        for(int i = 0;i<devList.size();i++){
//            String sql2 = "SELECT \"b\"  FROM \"tdl_policy\".\""+device+"\" where \"tdl\"=\'tdl-"+devList.get(i)+"\'and  time >= "+startTime +"  ORDER BY time desc limit 1";
//            QueryResult  queryResult2  = influxDBTemplate.query(new Query(sql2,database));
//            if(queryResult2.getResults().get(0).getSeries() != null){
//                List<List<Object>> values = getValues(queryResult2);
//                for(List<Object> value:values){
//                    resultCircuit.setTDLSN(devList.get(i));
//                    resultCircuit.setBatteryVoltage(value.get(1)==null ? "" :value.get(1).toString());
//                }
//            }
//        }
//        resultCircuit.setCircuitState(resultCircuitVo.getCircuitState());
//        return  gson.toJson(resultCircuit);
//    }


//    根据时间获取经纬度信息
//    @ApiOperation(value = "根据时间获取经纬度信息",notes = "根据时间获取经纬度信息" +
//            "transportationNo:运输编号" +
//            "TDLSN:tdl编号" +
//            "gatewaySN:网关编号" +
//            "startCity:出发城市" +
//            "endCity:目的城市" +
//            "startTime:出发时间" +
//            "endTime:到达时间" +
//            "alarmTime:报警时间" +
//            "alarmType:报警类型" +
//            "alarmValue:报警值" +
//            "lng:经度" +
//            "lat:纬度")
//    @PostMapping("/getLocationByTime")
//    @ApiImplicitParams({
//        @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
//    })
//    public Object getLocationByTime(@RequestBody LocationVo locationVo,HttpServletRequest request){
//        String token = request.getHeader("Account_token");
//        String datum = tokenRedisService.get("TOKEN_" +token);
//        UserRedisVo user =  gson.fromJson(datum,UserRedisVo.class);
//        //获取线路信息
//        //获取网关以及tdl信息
//        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(locationVo.getTransportationNo(),user.getCompanyName());
//        ResultGatewayVo gatewayVo = new ResultGatewayVo();
//        if(resultCircuitVo.getEndTime() == 0){
//            gatewayVo = circuitService.getByNo(locationVo.getTransportationNo());
//        }else{
//            gatewayVo = tdlLogService.getByNo(locationVo.getTransportationNo());
//        }
//        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
//        //获取tdl信息
//        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
//        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
//        //根据时间获取坐标信息
//        String sql ="SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\""+devcie+"\" where time = "+locationVo.getTime() *1000000l;
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        List<LocationMessageVo>  locationDataVos = new ArrayList<>();
//        if(queryResult.getResults().get(0).getSeries() != null){
//            List<List<Object>> values = getValues(queryResult);
//            for(List<Object> value:values){
//                LocationMessageVo messageVo = new LocationMessageVo();
//                messageVo.setTransportationNo(locationVo.getTransportationNo());
//                messageVo.setGatewaySN(gatewayVo.getSN());
//                messageVo.setTDLSN(devList);
//                messageVo.setStartCity(resultCircuitVo.getStartCity());
//                messageVo.setEndCity(resultCircuitVo.getEndCity());
//                messageVo.setStartTime(resultCircuitVo.getStartTime());
//                messageVo.setEndTime(resultCircuitVo.getEndTime());
//                messageVo.setAlarmTime(Long.valueOf(parseTime(value.get(0).toString())));
//                messageVo.setAlarmType(locationVo.getAlarmType());
//                messageVo.setAlarmValue(locationVo.getVlaue());
//                messageVo.setLng(value.get(1)==null ?  "" : value.get(1).toString());
//                messageVo.setLat(value.get(2)==null ?  "" : value.get(2).toString());
//                locationDataVos.add(messageVo);
//            }
//        }
//        return  gson.toJson(locationDataVos);
//    }
//
////    获取温度、湿度、震动强度、震动能量、倾斜度
//    @PostMapping("/getDeviceData")
//    @ApiImplicitParams({
//        @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
//    })
//    public Object getDeviceData(@RequestBody String transportationNo,HttpServletRequest request){
//        String token = request.getHeader("Account_token");
//        String datum = tokenRedisService.get("TOKEN_" +token);
//        UserRedisVo user =  gson.fromJson(datum,UserRedisVo.class);
//        JSONObject jsonObject= JSON.parseObject(transportationNo);
//        transportationNo=jsonObject.getString("transportationNo");
//        //获取网关以及tdl信息
//        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo,user.getCompanyName());
//        ResultGatewayVo gatewayVo = new ResultGatewayVo();
//        if(resultCircuitVo.getEndTime() == 0){
//            gatewayVo = circuitService.getByNo(transportationNo);
//        }else{
//            gatewayVo = tdlLogService.getByNo(transportationNo);
//        }
//        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
//        Long startTime = resultCircuitVo.getStartTime() *1000000l;
//        //获取tdl信息
//        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
//        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
//        //SELECT "h" FROM "tdl_policy"."WTD93LG_20180314" WHERE "tdl" = 'tdl-0A0B0C0D0F' ORDER BY time DESC
//        String sql = "SELECT \"t\",\"h\",\"p\",\"a0\",\"ta\" FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\" = \'"+devList.get(0)+"\' and  time>="+startTime+"  ORDER BY time ";
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        //解析经纬度数据
//        List<DeviceDataVo>  deviceDataVos = new ArrayList<>();
//        if(queryResult.getResults().get(0).getSeries() != null){
//            deviceDataVos= getDeviceData(queryResult);
//        }
//        return gson.toJson(deviceDataVos);
//    }
//
//
//    //    获取实时数据
//    @ApiOperation(value = "获取实时数据",notes = "获取实时数据")
//    @ApiImplicitParams({
//        @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
//    })
//    @PostMapping("/getRealTimeData")
//    public Object getRealTimeData(@RequestBody String transportationNo){
//        JSONObject jsonObject= JSON.parseObject(transportationNo);
//        transportationNo=jsonObject.getString("transportationNo");
//        //获取gateway的信息
//       // ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
//        ResultGatewayVo gatewayVo = new ResultGatewayVo();
//        if(gatewayVo==null){
//            fb.setCode(0);
//            fb.setMessage("该线路未绑定设备");
//            return gson.toJson(fb);
//        }
//        //获取tdl信息
//        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
//        //根据gateWay获取tdl信息
//        List<String> key = new ArrayList<>();
//        key.add(gatewayVo.getSN()+"_"+gatewayVo.getType() +":"+gatewayVo.getSN()+"_"+gatewayVo.getType());
//        for (int i = 0;i<devList.size();i++){
//            key.add(gatewayVo.getSN()+"_"+gatewayVo.getType()+":"+devList.get(i));
//        }
//        List<LiveDataVo> liveDataVos = new ArrayList<>();
//        for(int j=0;j<key.size();j++){
//            Map<Object,Object> ret = realRedisService.getHashAll(key.get(j));
//            if(ret == null){
//                continue;
//            }else{
//                Iterator entries = ret.entrySet().iterator();
//                List<String> aliasList = new ArrayList<>();
//                List<String> valueList = new ArrayList<>();
//                while(entries.hasNext()){
//                    Map.Entry entry = (Map.Entry) entries.next();
//                    aliasList.add((String) entry.getKey());
//                    valueList.add((String) entry.getValue());
//                }
//                //根据通道别名获取通道信息
//                List<ProbesVo> probesVoList =  probesService.getByAliasList(gatewayVo.getSN(),gatewayVo.getType(),aliasList);
//                for(int m = 0;m<probesVoList.size();m++){
//                    probesVoList.get(m).setValue(valueList.get(m));
//                }
//                LiveDataVo liveDataVo = new LiveDataVo();
//                liveDataVo.setKey(key.get(j).substring(key.get(j).indexOf(":"),key.get(j).length()));
//                liveDataVo.setProbesVoList(probesVoList);
//                liveDataVos.add(liveDataVo);
//            }
//        }
//        return  gson.toJson(liveDataVos);
//    }
//}